diff --git a/CDB/LOFAR_ConfigDb.json b/CDB/LOFAR_ConfigDb.json
index e6c6e0587aab5f509c9789e378a4f3ba72cb2e90..a0757924b736a04db12e3e908a52c51448eec754 100644
--- a/CDB/LOFAR_ConfigDb.json
+++ b/CDB/LOFAR_ConfigDb.json
@@ -710,10 +710,10 @@
                 }
             }
         },
-        "Statistics": {
+        "SST": {
             "LTS": {
-                "Statistics": {
-                    "LTS/Statistics/1": {
+                "SST": {
+                    "LTS/SST/1": {
                         "properties": {
                             "SST_Port": [
                                 "5001"
diff --git a/devices/clients/SDP_statistics.py b/devices/clients/StatisticsPacket.py
similarity index 100%
rename from devices/clients/SDP_statistics.py
rename to devices/clients/StatisticsPacket.py
diff --git a/devices/clients/sst_client.py b/devices/clients/sst_client.py
index d4823c16568e847a098073c0f5255781f1a47dbf..4ebf4a9aa76e4b626390f4c85dc0ad04a88ed34b 100644
--- a/devices/clients/sst_client.py
+++ b/devices/clients/sst_client.py
@@ -2,7 +2,7 @@ import queue
 from threading import Thread
 import socket
 from util.comms_client import CommClient
-from clients.SDP_statistics import StatisticsPacket
+from clients.StatisticsPacket import StatisticsPacket
 
 from queue import Queue
 
diff --git a/docker-compose/device-statistics.yml b/docker-compose/device-sst.yml
similarity index 82%
rename from docker-compose/device-statistics.yml
rename to docker-compose/device-sst.yml
index 4cd533b8e2ef43b584e5088ffc78ceead9ffe2b1..5d5b2501f72c3372f6e82f579a251f949948a549 100644
--- a/docker-compose/device-statistics.yml
+++ b/docker-compose/device-sst.yml
@@ -13,15 +13,15 @@
 version: '2'
 
 services:
-  device-statistics:
-    image: device-statistics
+  device-sst:
+    image: device-sst
     # build explicitly, as docker-compose does not understand a local image
     # being shared among services.
     build:
         context: lofar-device-base
         args:
             SOURCE_IMAGE: ${DOCKER_REGISTRY_HOST}/${DOCKER_REGISTRY_USER}/tango-itango:9.3.3.7
-    container_name: ${CONTAINER_NAME_PREFIX}device-statistics
+    container_name: ${CONTAINER_NAME_PREFIX}device-sst
     network_mode: ${NETWORK_MODE}
     ports:
     - 5001:5001/udp
@@ -35,5 +35,5 @@ services:
       - --timeout=30
       - --strict
       - --
-      - python3 -u ${TANGO_LOFAR_CONTAINER_DIR}/devices/Statistics.py LTS -v
+      - python3 -u ${TANGO_LOFAR_CONTAINER_DIR}/devices/SST.py LTS -v
     restart: on-failure
diff --git a/docker-compose/jupyter/ipython-profiles/stationcontrol-jupyter/startup/01-devices.py b/docker-compose/jupyter/ipython-profiles/stationcontrol-jupyter/startup/01-devices.py
index 441ef50f02110eb53b4a7f8cbe28fa906d0ba8ca..bc56f8b05de5e90804562bcf77378ae8798100a2 100644
--- a/docker-compose/jupyter/ipython-profiles/stationcontrol-jupyter/startup/01-devices.py
+++ b/docker-compose/jupyter/ipython-profiles/stationcontrol-jupyter/startup/01-devices.py
@@ -1,7 +1,7 @@
 # Create shortcuts for our devices
 pcc = DeviceProxy("LTS/PCC/1")
 sdp = DeviceProxy("LTS/SDP/1")
-statistics = DeviceProxy("LTS/Statistics/1")
+sst = DeviceProxy("LTS/SST/1")
 
 # Put them in a list in case one wants to iterate
-devices = [pcc, sdp, statistics]
+devices = [pcc, sdp, sst]
diff --git a/devices/Statistics.py b/devices/SST.py
similarity index 92%
rename from devices/Statistics.py
rename to devices/SST.py
index d599a9dbeb88411d9051072f142c8323930cfb09..f7387b5ad4a5b243fea1e6fa0eddd470c4c32dcf 100644
--- a/devices/Statistics.py
+++ b/devices/SST.py
@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of the Statistics project
 #
 #
 #
 # Distributed under the terms of the APACHE license.
 # See LICENSE.txt for more info.
 
 """ Statistics Device Server for LOFAR2.0
 
 """
 
@@ -27,10 +27,10 @@ from util.lofar_logging import device_logging_to_python, log_exceptions
 
 import numpy
 
-__all__ = ["Statistics", "main"]
+__all__ = ["SST", "main"]
 
-@device_logging_to_python({"device": "Statistics"})
-class Statistics(hardware_device):
+@device_logging_to_python({"device": "SST"})
+class SST(hardware_device):
 
     # -----------------
     # Device Properties
@@ -99,13 +99,13 @@ class Statistics(hardware_device):
 # Run server
 # ----------
 def main(args=None, **kwargs):
     """Main function of the Statistics Device module."""
 
     from util.lofar_logging import configure_logger
     import logging
     configure_logger(logging.getLogger())
 
-    return run((Statistics,), args=args, **kwargs)
+    return run((SST,), args=args, **kwargs)
 
 
 if __name__ == '__main__':
@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 #
-# This file is part of the Statistics project
+# This file is part of the SST project
 #
 #
@@ -1,13 +1,13 @@
 # See LICENSE.txt for more info.
 
-""" Statistics Device Server for LOFAR2.0
+""" SST Device Server for LOFAR2.0
 
 """
@@ -99,13 +99,13 @@ class Statistics(hardware_device):
 # ----------
 def main(args=None, **kwargs):
-    """Main function of the Statistics Device module."""
+    """Main function of the SST Device module."""
 
     from util.lofar_logging import configure_logger